@@ -34,6 +34,7 @@ from gnomemusic.player import ValidationStatus, PlayerPlaylist
 from gnomemusic.playlists import Playlists
 from gnomemusic.query import Query
 from gnomemusic.utils import View
+from gnomemusic.search import Search
 from gnomemusic.views.baseview import BaseView
 from gnomemusic.widgets.headerbar import HeaderBar
 from gnomemusic.widgets.albumwidget import AlbumWidget
@@ -45,9 +46,7 @@ playlists = Playlists.get_default()
 
 class SearchView(BaseView):
 
-    __gsignals__ = {
-        'no-music-found': (GObject.SignalFlags.RUN_FIRST, None, ())
-    }
+    search_state = GObject.Property(type=int, default=Search.State.NONE)
 
     def __repr__(self):
         return '<SearchView>'
@@ -65,7 +64,6 @@ class SearchView(BaseView):
         self._filter_model = None
 
         self.previous_view = None
-        self.connect('no-music-found', self._no_music_found_callback)
 
         self._albums_selected = []
         self._albums = {}
@@ -96,15 +94,13 @@ class SearchView(BaseView):
         self._view.get_style_context().add_class('content-view')
         self._view.get_selection().props.mode = Gtk.SelectionMode.NONE
         self._view.connect('row-activated', self._on_item_activated)
-        self._view.connect('button-release-event', self._on_view_clicked)
+
+        self._ctrl = Gtk.GestureMultiPress().new(self._view)
+        self._ctrl.props.propagation_phase = Gtk.PropagationPhase.CAPTURE
+        self._ctrl.connect("released", self._on_view_clicked)
 
         view_container.add(self._view)
 
-    @log
-    def _no_music_found_callback(self, view):
-        # FIXME: call into private members
-        self._window._stack.set_visible_child_name("emptyview")
-
     @log
     def _back_button_clicked(self, widget, data=None):
         self._searchbar.reveal(True, False)
@@ -145,7 +141,8 @@ class SearchView(BaseView):
             self._headerbar.props.title = title
             self._headerbar.props.subtitle = artist
             self.set_visible_child(self._album_widget)
-            self._searchbar.reveal(False)
+            self.props.search_state = Search.State.NONE
+
         elif self.model[_iter][12] == 'artist':
             artist = self.model[_iter][2]
             albums = self._artists[artist.casefold()]['albums']
@@ -163,8 +160,9 @@ class SearchView(BaseView):
 
             self._headerbar.props.state = HeaderBar.State.SEARCH
             self._headerbar.props.title = artist
+            self._headerbar.props.subtitle = None
             self.set_visible_child(self._artist_albums_widget)
-            self._searchbar.reveal(False)
+            self.props.search_state = Search.State.NONE
         elif self.model[_iter][12] == 'song':
             if self.model[_iter][11] != ValidationStatus.FAILED:
                 c_iter = self._songs_model.convert_child_iter_to_iter(_iter)[1]
@@ -179,21 +177,17 @@ class SearchView(BaseView):
                 self._view.expand_row(path, False)
 
     @log
-    def _on_view_clicked(self, treeview, event):
-        """Ctrl+click on self._view triggers selection mode.
-
-        :param Gtk.TreeView treeview: self._view
-        :param Gdk.EventButton event: clicked event
-        """
+    def _on_view_clicked(self, gesture, n_press, x, y):
+        """Ctrl+click on self._view triggers selection mode."""
+        _, state = Gtk.get_current_event_state()
         modifiers = Gtk.accelerator_get_default_mod_mask()
-        if ((event.state & modifiers) == Gdk.ModifierType.CONTROL_MASK
+        if (state & modifiers == Gdk.ModifierType.CONTROL_MASK
                 and not self.props.selection_mode):
             self._on_selection_mode_request()
 
         if (self.selection_mode
                 and not self._star_handler.star_renderer_click):
-            path, col, cell_x, cell_y = treeview.get_path_at_pos(
-                event.x, event.y)
+            path, col, cell_x, cell_y = self._view.get_path_at_pos(x, y)
             iter_ = self.model.get_iter(path)
             self.model[iter_][6] = not self.model[iter_][6]
             selected_iters = self._get_selected_iters()
@@ -225,7 +219,7 @@ class SearchView(BaseView):
         if not item:
             if (grilo._search_callback_counter == 0
                     and grilo.search_source):
-                self.emit('no-music-found')
+                self.props.search_state = Search.State.NO_RESULT
             return
 
         if data != self.model:
@@ -270,18 +264,17 @@ class SearchView(BaseView):
             + self.model.iter_n_children(self._head_iters[3])
         )
 
-        if (category == 'song'
-                and self._items_found == 0
-                and remaining == 0):
-            if grilo.search_source:
-                self.emit('no-music-found')
-
         # We need to remember the view before the search view
         emptysearchview = self._window.views[View.EMPTY]
         if (self._window.curr_view != emptysearchview
                 and self._window.prev_view != emptysearchview):
             self.previous_view = self._window.prev_view
 
+        if self._items_found == 0:
+            self.props.search_state = Search.State.NO_RESULT
+        else:
+            self.props.search_state = Search.State.RESULT
+
         if remaining == 0:
             self._window.notifications_popup.pop_loading()
             self._view.show()
